@@ -59,8 +59,8 @@ namespace ttcr {
         dx(ddx), dz(ddz), xmin(minx), zmin(minz),
         xmax(minx+nx*ddx), zmax(minz+nz*ddz),
         ncx(nx), ncz(nz),
-        nodes(std::vector<NODE>( (ncx+1) * (ncz+1), NODE(nt) )),
-        cells(ncx*ncz)
+        nodes(std::vector<NODE>( static_cast<size_t>(ncx+1) * (ncz+1), NODE(nt) )),
+        cells(static_cast<size_t>(ncx)*ncz)
         {
         }
 
@@ -68,8 +68,8 @@ namespace ttcr {
         }
 
         void getSlowness(std::vector<T1>& slowness) const {
-            if (slowness.size() != ncx*ncz) {
-                slowness.resize(ncx*ncz);
+            if (slowness.size() != static_cast<size_t>(ncx)*ncz) {
+                slowness.resize(static_cast<size_t>(ncx)*ncz);
             }
             for (size_t n=0; n<slowness.size(); ++n) {
                 slowness[n] = cells.getSlowness(n);
@@ -135,15 +135,15 @@ namespace ttcr {
 
         size_t getNumberOfNodes(const bool primary=false) const {
             if ( primary ) {
-                return (ncx+1) * (ncz+1);
+                return static_cast<size_t>(ncx+1) * (ncz+1);
             } else {
                 return nodes.size();
             }
         }
-        size_t getNumberOfCells() const { return ncx*ncz; }
+        size_t getNumberOfCells() const { return static_cast<size_t>(ncx)*ncz; }
 
         void getTT(std::vector<T1>& tt, const size_t threadNo=0) const {
-            size_t nPrimary = (ncx+1) * (ncz+1);
+            size_t nPrimary = static_cast<size_t>(ncx+1) * (ncz+1);
             tt.resize(nPrimary);
             size_t n = 0;
             for ( size_t nn=0; nn<nodes.size(); ++nn ) {
@@ -189,7 +189,7 @@ namespace ttcr {
         const T2 getNcz() const { return ncz; }
 
         void dump_secondary(std::ofstream& os) const {
-            size_t nPrimary = (ncx+1) * (ncz+1);
+            size_t nPrimary = static_cast<size_t>(ncx+1) * (ncz+1);
             for ( size_t n=nPrimary; n<nodes.size(); ++n ) {
                 os << nodes[n].getX() << ' ' << nodes[n].getZ() << '\n';
             }
@@ -254,6 +254,13 @@ namespace ttcr {
                         T1 &tt,
                         const size_t threadNo) const final;
 
+        void getRaypath(const std::vector<S>& Tx,
+                        const std::vector<T1>& t0,
+                        const S& Rx,
+                        std::vector<siv<T1>> &l_data,
+                        T1 &tt,
+                        const size_t threadNo) const final;
+
     };
 
     template<typename T1, typename T2, typename S, typename NODE, typename CELL>
@@ -917,8 +924,13 @@ namespace ttcr {
                         tt += cells.computeDt(r_data.back(), curr_pt, cell.i);
                         r_data.push_back( curr_pt );
                         // to Tx
-                        cell.i = getCellNo(Tx[ns]);
-                        cell.v = Tx[ns].getDistance(r_data.back());
+                        size_t itmp = getCellNo(Tx[ns]);
+                        if ( cell.i == itmp ) {
+                            cell.v += Tx[ns].getDistance(r_data.back());
+                        } else {
+                            cell.i = itmp;
+                            cell.v = Tx[ns].getDistance(r_data.back());
+                        }
                         l_data.push_back(cell);
                         tt += cells.computeDt(Tx[ns], curr_pt, cell.i);
                         r_data.push_back( Tx[ns] );
@@ -930,6 +942,146 @@ namespace ttcr {
             }
         }
     }
+
+    template<typename T1, typename T2, typename S, typename NODE, typename CELL>
+    void Grid2Drc<T1,T2,S,NODE,CELL>::getRaypath(const std::vector<S>& Tx,
+                                                 const std::vector<T1>& t0,
+                                                 const S& Rx,
+                                                 std::vector<siv<T1>> &l_data,
+                                                 T1 &tt,
+                                                 const size_t threadNo) const {
+        tt = 0.0;
+        
+        for ( size_t ns=0; ns<Tx.size(); ++ns ) {
+            if ( Rx == Tx[ns] ) {
+                tt = t0[ns];
+                return;
+            }
+        }
+        
+        S curr_pt( Rx );
+        S prev_pt( Rx );
+        // distance between opposite nodes of a voxel
+        const T1 maxDist = sqrt( dx*dx + dz*dz );
+        S g;
+        
+        siv<T1> cell;
+        bool reachedTx = false;
+        while ( reachedTx == false ) {
+            
+            grad(g, curr_pt, threadNo);
+            g *= -1.0;
+            
+            long long i, k;
+            getIJ(curr_pt, i, k);
+            
+            // planes we will intersect
+            T1 xp = xmin + dx*(i + (boost::math::sign(g.x)>0.0 ? 1.0 : 0.0));
+            T1 zp = zmin + dz*(k + (boost::math::sign(g.z)>0.0 ? 1.0 : 0.0));
+            
+            if ( std::abs(xp-curr_pt.x)<small) {
+                xp += dx*boost::math::sign(g.x);
+            }
+            if ( std::abs(zp-curr_pt.z)<small) {
+                zp += dz*boost::math::sign(g.z);
+            }
+            
+            // dist to planes
+            T1 tx = g.x!=0.0 ? (xp - curr_pt.x)/g.x : std::numeric_limits<T1>::max();
+            T1 tz = g.z!=0.0 ? (zp - curr_pt.z)/g.z : std::numeric_limits<T1>::max();
+            
+            if ( tx<tz ) { // closer to xp
+                curr_pt += tx*g;
+                curr_pt.x = xp;     // make sure we don't accumulate rounding errors
+            } else {
+                curr_pt += tz*g;
+                curr_pt.z = zp;
+            }
+            
+            if ( curr_pt.x < xmin || curr_pt.x > xmax ||
+                curr_pt.z < zmin || curr_pt.z > zmax ) {
+                //  we are going oustide the grid!
+                std::ostringstream msg;
+                msg << "Error while computing raypaths: going outside grid \n\
+            Rx: " << Rx << "\n\
+            Tx: " << Tx[0] << "\n";
+                for ( size_t ns=1; ns<Tx.size(); ++ns ) {
+                    msg << "\
+                " << Tx[ns] << "\n";
+                }
+                throw std::runtime_error(msg.str());
+            }
+            
+            S mid_pt = static_cast<T1>(0.5)*(prev_pt + curr_pt);
+            cell.i = getCellNo(mid_pt);
+            cell.v = curr_pt.getDistance(prev_pt);
+            l_data.push_back(cell);
+            tt += cells.computeDt(prev_pt, curr_pt, cell.i);
+            prev_pt = curr_pt;
+            
+            // are we close enough to one the Tx nodes ?
+            for ( size_t ns=0; ns<Tx.size(); ++ns ) {
+                T1 dist = curr_pt.getDistance( Tx[ns] );
+                if ( dist < maxDist ) {
+                    
+                    g = Tx[ns] - curr_pt;
+                    
+                    T1 xp = xmin + dx*(i + (boost::math::sign(g.x)>0.0 ? 1.0 : 0.0));
+                    T1 zp = zmin + dz*(k + (boost::math::sign(g.z)>0.0 ? 1.0 : 0.0));
+                    
+                    if ( std::abs(xp-curr_pt.x)<small) {
+                        xp += dx*boost::math::sign(g.x);
+                    }
+                    if ( std::abs(zp-curr_pt.z)<small) {
+                        zp += dz*boost::math::sign(g.z);
+                    }
+                    
+                    // dist to planes
+                    T1 tx = g.x!=0.0 ? (xp - curr_pt.x)/g.x : std::numeric_limits<T1>::max();
+                    T1 tz = g.z!=0.0 ? (zp - curr_pt.z)/g.z : std::numeric_limits<T1>::max();
+                    
+                    if ( tx<tz ) { // closer to xp
+                        curr_pt += tx*g;
+                        curr_pt.x = xp;     // make sure we don't accumulate rounding errors
+                    } else {
+                        curr_pt += tz*g;
+                        curr_pt.z = zp;
+                    }
+                    
+                    if ( curr_pt.getDistance(prev_pt) > dist ||  // we do not intersect
+                        curr_pt == Tx[ns] ) {  // we have arrived
+                        cell.i = getCellNo(Tx[ns]);
+                        cell.v = Tx[ns].getDistance(prev_pt);
+                        l_data.push_back(cell);
+                        tt += cells.computeDt(Tx[ns], prev_pt, cell.i);
+                        
+                    } else {
+                        // to intersection
+                        mid_pt = static_cast<T1>(0.5)*(prev_pt + curr_pt);
+                        cell.i = getCellNo(mid_pt);
+                        cell.v = curr_pt.getDistance(prev_pt);
+                        l_data.push_back(cell);
+                        tt += cells.computeDt(prev_pt, curr_pt, cell.i);
+                        prev_pt = curr_pt;
+                        // to Tx
+                        size_t itmp = getCellNo(Tx[ns]);
+                        if ( cell.i == itmp ) {
+                            cell.v += Tx[ns].getDistance(prev_pt);
+                        } else {
+                            cell.i = itmp;
+                            cell.v = Tx[ns].getDistance(prev_pt);
+                        }
+                        l_data.push_back(cell);
+                        tt += cells.computeDt(Tx[ns], curr_pt, cell.i);
+                    }
+                    
+                    tt += t0[ns];
+                    reachedTx = true;
+                }
+            }
+        }
+    }
+
 }
 
 #endif /* Grid2Drc_h */
