@@ -80,8 +80,8 @@ namespace ttcr {
         virtual ~Grid3Drc() {}
 
         void getSlowness(std::vector<T1>& slowness) const {
-            if (slowness.size() != ncx*ncy*ncz) {
-                slowness.resize(ncx*ncy*ncz);
+            if (slowness.size() != static_cast<size_t>(ncx)*ncy*ncz) {
+                slowness.resize(static_cast<size_t>(ncx)*ncy*ncz);
             }
             for (size_t n=0; n<slowness.size(); ++n) {
                 slowness[n] = cells.getSlowness(n);
@@ -102,10 +102,10 @@ namespace ttcr {
         }
 
         size_t getNumberOfNodes() const { return nodes.size(); }
-        size_t getNumberOfCells() const { return ncx*ncy*ncz; }
+        size_t getNumberOfCells() const { return static_cast<size_t>(ncx)*ncy*ncz; }
 
         void getTT(std::vector<T1>& tt, const size_t threadNo=0) const final {
-            size_t nPrimary = (ncx+1) * (ncy+1) * (ncz+1);
+            size_t nPrimary = static_cast<size_t>(ncx+1) * (ncy+1) * (ncz+1);
             tt.resize(nPrimary);
             for ( size_t n=0; n<nPrimary; ++n ) {
                 tt[n] = nodes[n].getTT(threadNo);
@@ -166,13 +166,16 @@ namespace ttcr {
         const T2 getNcz() const { return ncz; }
 
         void dump_secondary(std::ofstream& os) const {
-            size_t nPrimary = (ncx+1) * (ncy+1) * (ncz+1);
+            size_t nPrimary = static_cast<size_t>(ncx+1) * (ncy+1) * (ncz+1);
             for ( size_t n=nPrimary; n<nodes.size(); ++n ) {
                 os << nodes[n].getX() << ' ' << nodes[n].getY() << ' ' << nodes[n].getZ() << '\n';
             }
         }
 
-        T1 computeSlowness(const sxyz<T1>& pt) const {
+        T1 computeSlowness(sxyz<T1> pt, const bool isTranslated=false) const {
+            if (this->translateOrigin == true && isTranslated == false) {
+                pt -= this->origin;
+            }
             return cells.getSlowness(getCellNo(pt));
         }
 
@@ -235,7 +238,7 @@ namespace ttcr {
             k = static_cast<long long>( small2 + (pt.z-zmin)/dz );
         }
 
-        void checkPts(const std::vector<sxyz<T1>>&) const;
+        void checkPts(std::vector<sxyz<T1>> pts, const bool translated=false) const;
 
         T1 getTraveltime(const sxyz<T1>& Rx,
                          const std::vector<NODE>& nodes,
@@ -300,6 +303,9 @@ namespace ttcr {
 
         if ( this->translateOrigin ) {
             this->origin = {xmin, ymin, zmin};
+            xmax -= xmin;
+            ymax -= ymin;
+            zmax -= zmin;
             xmin = 0.0;
             ymin = 0.0;
             zmin = 0.0;
@@ -655,7 +661,13 @@ namespace ttcr {
 
 
     template<typename T1, typename T2, typename NODE, typename CELL>
-    void Grid3Drc<T1,T2,NODE,CELL>::checkPts(const std::vector<sxyz<T1>>& pts) const {
+    void Grid3Drc<T1,T2,NODE,CELL>::checkPts(std::vector<sxyz<T1>> pts, const bool translated) const {
+
+        if (this->translateOrigin == true && translated == false) {
+            for ( size_t n=0; n<pts.size(); ++n ) {
+                pts[n] -= this->origin;
+            }
+        }
 
         // Check if the points from a vector are in the grid
         for ( size_t n=0; n<pts.size(); ++n ) {
@@ -663,7 +675,7 @@ namespace ttcr {
                 pts[n].y < ymin || pts[n].y > ymax ||
                 pts[n].z < zmin || pts[n].z > zmax ) {
                 std::ostringstream msg;
-                msg << "Error: Point (" << pts[n].x << ", " << pts[n].y << ", " << pts[n] .z << ") outside grid.";
+                msg << "Error: Point (" << pts[n] << ") outside grid.";
                 throw std::runtime_error(msg.str());
             }
         }
