@@ -57,7 +57,7 @@ namespace ttcr {
             this->template buildGridNeighbors<Node3Dc<T1,T2>>(this->nodes);
             nPermanent = static_cast<T2>(this->nodes.size());
             for ( size_t n=0; n<nt; ++n ) {
-                tempNeighbors[n].resize(this->ncx * this->ncy * this->ncz);
+                tempNeighbors[n].resize(static_cast<size_t>(this->ncx) * this->ncy * this->ncz);
             }
             if (useEdgeLength) {
                 T1 dx = 0.3333333 * (ddx+ddy+ddz);
@@ -693,8 +693,8 @@ namespace ttcr {
                                            const std::vector<T1>& t0,
                                            const std::vector<sxyz<T1>>& Rx,
                                            const size_t threadNo) const {
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -720,9 +720,9 @@ namespace ttcr {
                                            const std::vector<T1>& t0,
                                            const std::vector<std::vector<sxyz<T1>>>& Rx,
                                            const size_t threadNo) const {
-        this->checkPts(Tx);
+        this->checkPts(Tx, true);
         for ( size_t n=0; n<Rx.size(); ++n ) {
-            this->checkPts(Rx[n]);
+            this->checkPts(Rx[n], true);
         }
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
