@@ -50,7 +50,7 @@ namespace ttcr {
             this->template buildGridNeighbors<Node3Dn<T1,T2>>(this->nodes);
             nPermanent = static_cast<T2>(this->nodes.size());
             for ( size_t n=0; n<nt; ++n ) {
-                tempNeighbors[n].resize(this->ncx * this->ncy * this->ncz);
+                tempNeighbors[n].resize(static_cast<size_t>(this->ncx) * this->ncy * this->ncz);
             }
             if (useEdgeLength) {
                 T1 dx = 0.3333333 * (ddx+ddy+ddz);
@@ -788,7 +788,7 @@ namespace ttcr {
                 txNodes.back().pushOwner( this->getCellNo(Tx[n]) );
                 txNodes.back().setGridIndex( static_cast<T2>(this->nodes.size()+txNodes.size()-1) );
                 frozen.push_back( true );
-                T1 slo = this->computeSlowness( Tx[n] );
+                T1 slo = this->computeSlowness( Tx[n], true );
                 txNodes.back().setNodeSlowness( slo );
 
                 queue.push( &(txNodes.back()) );
@@ -862,8 +862,8 @@ namespace ttcr {
                                       const std::vector<T1>& t0,
                                       const std::vector<sxyz<T1>>& Rx,
                                       const size_t threadNo) const {
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -889,9 +889,9 @@ namespace ttcr {
                                       const std::vector<T1>& t0,
                                       const std::vector<std::vector<sxyz<T1>>>& Rx,
                                       const size_t threadNo) const {
-        this->checkPts(Tx);
+        this->checkPts(Tx, true);
         for ( size_t n=0; n<Rx.size(); ++n ) {
-            this->checkPts(Rx[n]);
+            this->checkPts(Rx[n], true);
         }
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
