@@ -173,8 +173,8 @@ namespace ttcr {
             }
         }
 
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -233,9 +233,9 @@ namespace ttcr {
             }
         }
 
-        this->checkPts(Tx);
+        this->checkPts(Tx, true);
         for ( size_t n=0; n<Rx.size(); ++n ) {
-            this->checkPts(Rx[n]);
+            this->checkPts(Rx[n], true);
         }
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
@@ -295,8 +295,8 @@ namespace ttcr {
             }
         }
 
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -421,9 +421,9 @@ namespace ttcr {
             }
         }
 
-        this->checkPts(Tx);
+        this->checkPts(Tx, true);
         for ( size_t n=0; n<Rx.size(); ++n ) {
-            this->checkPts(Rx[n]);
+            this->checkPts(Rx[n], true);
         }
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
@@ -565,8 +565,8 @@ namespace ttcr {
             }
         }
 
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -733,7 +733,7 @@ namespace ttcr {
                 txNodes.back().pushOwner( this->getCellNo(Tx[n]) );
                 txNodes.back().setGridIndex( static_cast<T2>(this->nodes.size()+txNodes.size()-1) );
                 frozen.push_back( true );
-                T1 slo = this->computeSlowness( Tx[n] );
+                T1 slo = this->computeSlowness( Tx[n], true );
                 txNodes.back().setNodeSlowness( slo );
 
                 prepropagate(txNodes.back(), queue, inQueue, frozen, threadNo); // See description in the function declaration
