@@ -187,7 +187,7 @@ namespace ttcr {
         // edge nodes
         T2 nTmpNodes = 0;
         Node3Dnd<T1,T2> tmpNode;
-        size_t nDynTot = (nSecondary+1) * nTertiary;  // total number of dynamic nodes on edges
+        size_t nDynTot = static_cast<size_t>(nTertiary) * (nSecondary+1);  // total number of dynamic nodes on edges
 
         T1 slope, islown;
 
@@ -551,8 +551,8 @@ namespace ttcr {
                                       const std::vector<T1>& t0,
                                       const std::vector<sxyz<T1>>& Rx,
                                       const size_t threadNo) const {
-        this->checkPts(Tx);
-        this->checkPts(Rx);
+        this->checkPts(Tx, true);
+        this->checkPts(Rx, true);
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
             this->nodes[n].reinit( threadNo );
@@ -578,9 +578,9 @@ namespace ttcr {
                                       const std::vector<T1>& t0,
                                       const std::vector<std::vector<sxyz<T1>>>& Rx,
                                       const size_t threadNo) const {
-        this->checkPts(Tx);
+        this->checkPts(Tx, true);
         for ( size_t n=0; n<Rx.size(); ++n ) {
-            this->checkPts(Rx[n]);
+            this->checkPts(Rx[n], true);
         }
 
         for ( size_t n=0; n<this->nodes.size(); ++n ) {
