@@ -165,7 +165,7 @@ int body(const input_parameters &par) {
         }
 #else
         std::cerr << "Error: Program not compiled with VTK support" << std::endl;
-        return nullptr;
+        return 1;
 #endif
     }
 
@@ -313,7 +313,7 @@ int body(const input_parameters &par) {
                 size_t blk_end = blk_start + blk_size;
 
                 threads[i]=thread( [&g,&src,&rcv,&r_data,&reflectors,&all_rcv,
-                                    &rfl_r_data,&rfl2_r_data,
+                                    &rfl_r_data,&rfl2_r_data,&par,
                                     blk_start,blk_end,i]{
 
                     for ( size_t n=blk_start; n<blk_end; ++n ) {
@@ -334,6 +334,19 @@ int body(const input_parameters &par) {
                             abort();
                         }
 
+                        if ( par.saveGridTT>0 ) {
+
+                            string srcname = par.srcfiles[n];
+                            size_t pos = srcname.rfind("/");
+                            srcname.erase(0, pos+1);
+                            pos = srcname.rfind(".");
+                            size_t len = srcname.length()-pos;
+                            srcname.erase(pos, len);
+
+                            string filename = par.basename+"_"+srcname+"_all_tt";
+                            g->saveTT(filename, 0, n, par.saveGridTT);
+                        }
+
                         for ( size_t nr=0; nr<reflectors.size(); ++nr ) {
                             try {
                                 g->raytrace(reflectors[nr].get_coord(),
@@ -367,6 +380,19 @@ int body(const input_parameters &par) {
                     abort();
                 }
 
+                if ( par.saveGridTT>0 ) {
+
+                    string srcname = par.srcfiles[n];
+                    size_t pos = srcname.rfind("/");
+                    srcname.erase(0, pos+1);
+                    pos = srcname.rfind(".");
+                    size_t len = srcname.length()-pos;
+                    srcname.erase(pos, len);
+
+                    string filename = par.basename+"_"+srcname+"_all_tt";
+                    g->saveTT(filename, 0, n, par.saveGridTT);
+                }
+
                 for ( size_t nr=0; nr<reflectors.size(); ++nr ) {
                     try {
                         g->raytrace(reflectors[nr].get_coord(),
@@ -452,6 +478,19 @@ int body(const input_parameters &par) {
                             abort();
                         }
 
+                        if ( par.saveGridTT>0 ) {
+
+                            string srcname = par.srcfiles[n];
+                            size_t pos = srcname.rfind("/");
+                            srcname.erase(0, pos+1);
+                            pos = srcname.rfind(".");
+                            size_t len = srcname.length()-pos;
+                            srcname.erase(pos, len);
+
+                            string filename = par.basename+"_"+srcname+"_all_tt";
+                            g->saveTT(filename, 0, n, par.saveGridTT);
+                        }
+
                         for ( size_t nr=0; nr<reflectors.size(); ++nr ) {
                             try {
                                 g->raytrace(reflectors[nr].get_coord(),
@@ -483,6 +522,19 @@ int body(const input_parameters &par) {
                     abort();
                 }
 
+                if ( par.saveGridTT>0 ) {
+
+                    string srcname = par.srcfiles[n];
+                    size_t pos = srcname.rfind("/");
+                    srcname.erase(0, pos+1);
+                    pos = srcname.rfind(".");
+                    size_t len = srcname.length()-pos;
+                    srcname.erase(pos, len);
+
+                    string filename = par.basename+"_"+srcname+"_all_tt";
+                    g->saveTT(filename, 0, n, par.saveGridTT);
+                }
+
                 for ( size_t nr=0; nr<reflectors.size(); ++nr ) {
                     try {
                         g->raytrace(reflectors[nr].get_coord(),
