@@ -376,6 +376,12 @@ namespace ttcr {
         }
     };
 
+    template<typename T>
+    std::ostream& operator<< (std::ostream& os, const struct siv<T> &s) {
+        os << s.i << ' ' << s.v;
+        return os;
+    }
+
     template<typename T>
     struct sijv {
         size_t i;  // index in 1st dim
